pub fn unknown_reference_class_warnings(
bibliography: &Bibliography,
) -> Vec<Warning>Expand description
Scan the bibliography for unknown reference classes and return compatibility warnings.
pub fn unknown_reference_class_warnings(
bibliography: &Bibliography,
) -> Vec<Warning>Scan the bibliography for unknown reference classes and return compatibility warnings.