pub struct ParsedCitation {
pub start: usize,
pub end: usize,
pub citation: Citation,
pub placement: CitationPlacement,
pub structure: CitationStructure,
}Expand description
A citation marker parsed from a document.
Fields
start: usizeByte offset where the citation marker starts in the source document.
end: usizeByte offset immediately after the citation marker in the source document.
citation: CitationThe parsed citation payload and its items.
placement: CitationPlacementWhere the citation was found in the source document.
structure: CitationStructureStructural scope metadata for this citation location.