get_variable_key

Function get_variable_key 

pub fn get_variable_key(component: &TemplateComponent) -> Option<String>
Get a unique key for a template component’s variable.

The key includes rendering context (prefix/suffix) to allow the same variable to render multiple times if it appears in semantically different contexts. This enables styles like Chicago that require year after author AND after publisher.