Reference types for the Citum processor.
This module re-exports types from citum_schema (for citations) and csl_legacy
(for CSL-JSON bibliography data) for backward compatibility.
For new data, prefer using citum_schema::reference::InputReference which
provides a more type-safe model with EDTF date support.
Structs
- Citation
- A citation containing one or more references.
- Citation
Item - A single citation item referencing a bibliography entry.
- Contributor
List - A list of contributors.
- Edtf
String - An EDTF string.
- Flat
Name - A flattened name for internal processing.
- Reference
- The Reference model: a class-specific overlay reachable through accessor methods.
- Simple
Name - A simple name is just a string, with an optional location.
- Structured
Name - A structured name is a name broken down into its constituent parts.
Enums
- Citation
Mode - Citation mode for author-date styles.
- Contributor
- A contributor can be a single string, a structured name, or a list of contributors.
- Locator
Type - Locator types for pinpoint citations.
- Multilingual
String - A string that can be represented in multiple languages and scripts.
- NumOr
Str - A value that could be either a number or a string.
- Title
- A title can be a single string, a structured title, or a multilingual title.
Type Aliases
- Bibliography
- A bibliography is a collection of references keyed by ID.