LocatorType

Enum LocatorType 

pub enum LocatorType {
Show 37 variants Book, Chapter, Clause, Column, Corollary, Definition, Division, Figure, Folio, Line, Lemma, Note, Number, Opus, Page, Paragraph, Subparagraph, Subclause, Subdivision, Subsection, Part, Problem, Proposition, Recital, Schedule, Section, Surah, Theorem, SubVerbo, Supplement, Verse, Volume, VolumePeriodical, VolumeBook, Issue, Algorithm, Custom(String),
}
Locator types for pinpoint citations.

Variants



Book

Locator refers to a book within a larger work.



Chapter

Locator refers to a chapter.



Clause

Locator refers to a clause.



Column

Locator refers to a column.



Corollary

Locator refers to a corollary.



Definition

Locator refers to a definition.



Division

Locator refers to a division.



Figure

Locator refers to a figure.



Folio

Locator refers to a folio.



Line

Locator refers to a numbered line.



Lemma

Locator refers to a lemma.



Note

Locator refers to a note.



Number

Locator refers to a numbered unit.



Opus

Locator refers to an opus number.



Page

Locator refers to a page.



Paragraph

Locator refers to a paragraph.



Subparagraph

Locator refers to a sub-paragraph.



Subclause

Locator refers to a sub-clause.



Subdivision

Locator refers to a sub-division.



Subsection

Locator refers to a sub-section.



Part

Locator refers to a part or division.



Problem

Locator refers to a problem.



Proposition

Locator refers to a proposition.



Recital

Locator refers to a recital.



Schedule

Locator refers to a schedule.



Section

Locator refers to a section.



Surah

Locator refers to a surah.



Theorem

Locator refers to a theorem.



SubVerbo

Locator refers to an entry under a headword.



Supplement

Locator refers to a supplement.



Verse

Locator refers to a verse.



Volume

Locator refers to a volume.



VolumePeriodical

Locator refers to a periodical volume.



VolumeBook

Locator refers to a monograph volume.



Issue

Locator refers to an issue.



Algorithm

Locator refers to an algorithm.



Custom(String)

Locator refers to a custom pinpoint label.

Implementations

Source

impl LocatorType

pub fn as_key(&self) -> Cow<'_, str>

Return the canonical kebab-case key for this locator label.

pub fn from_key(value: &str) -> Result<LocatorType, String>

Parse a locator label from a known keyword or custom identifier.

Errors

Returns an error when the input is empty or normalizes to an empty key.