Module bibliography

Module bibliography 

Bibliography-level rendering and output assembly helpers.

Functions

refs_to_string
Render processed templates into a final bibliography string using PlainText format.
refs_to_string_slice_with_format
Render borrowed processed templates into a final bibliography string using a specific format.
refs_to_string_with_format
Render processed templates into a final bibliography string using a specific format.
render_entry_body_with_format
Render one processed bibliography entry body without outer entry/bibliography wrappers.