Module citation

Module citation 

Citation-level rendering and output assembly helpers.

Functions

citation_to_string
Render a processed template into a final citation string using PlainText format.
citation_to_string_with_format
Render a processed template into a final citation string using a specific format.