pub fn get_effective_rendering(component: &ProcTemplateComponent) -> RenderingExpand description
Get effective rendering, applying global config, then local template settings, then type-specific overrides.
pub fn get_effective_rendering(component: &ProcTemplateComponent) -> RenderingGet effective rendering, applying global config, then local template settings, then type-specific overrides.