pub fn render_component(component: &ProcTemplateComponent) -> StringExpand description
Render a single component to string using the default PlainText format.
pub fn render_component(component: &ProcTemplateComponent) -> StringRender a single component to string using the default PlainText format.