Output format trait for pluggable renderers.
Structs
- Proc
Entry Metadata - Metadata for a processed bibliography entry, used for interactivity.
- Quote
Marks - Locale-resolved quote mark characters, threaded from
GrammarOptionsthrough to rendering so that styles using non-English quotation conventions (e.g. fr-FR guillemets) render correctly. - Semantic
Attribute - Extra attributes applied to semantic wrappers when a renderer supports them.
Traits
- Output
Format - Trait for defining how to render template components into a specific format.
Functions
- unicode_
quote_ marks - Return Unicode quote marks for a nesting depth.