Module rich_text

Module rich_text 

Djot and org-mode inline markup rendering for free-text fields.

Structs

InlineRenderContext
Ambient context used while rendering inline rich text.

Functions

render_djot_inline
Render djot inline markup and map events to OutputFormat methods.
render_djot_inline_with_context
Render djot inline markup with an ambient inline rendering context.
render_org_inline
Render org-mode inline markup by walking the orgize event stream.