pub fn effective_component_language(
reference: &Reference,
component: &TemplateComponent,
) -> Option<String>Expand description
Resolve the effective language for the specific template component being rendered.
pub fn effective_component_language(
reference: &Reference,
component: &TemplateComponent,
) -> Option<String>Resolve the effective language for the specific template component being rendered.