effective_field_language

Function effective_field_language 

pub fn effective_field_language(
    reference: &Reference,
    scope: &str,
    title: Option<&Title>,
) -> Option<String>
Resolve the effective language for one logical field scope on a reference.

This prefers an explicit field_languages entry, then a multilingual title language tag for the provided title value, and finally the reference-level language.