ComponentValues

Trait ComponentValues 

pub trait ComponentValues {
    // Required method
    fn values<F: OutputFormat<Output = String>>(
        &self,
        reference: &Reference,
        hints: &ProcHints,
        options: &RenderOptions<'_>,
    ) -> Option<ProcValues<F::Output>>;
}
Trait for extracting values from template components.

Required Methods

fn values<F: OutputFormat<Output = String>>( &self, reference: &Reference, hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Resolve the component into processed render values for one reference.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ComponentValues for TemplateGroup

Source

fn values<F: OutputFormat<Output = String>>( &self, reference: &Reference, hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Returns the resolved list of component values for rendering.

Source

impl ComponentValues for TemplateNumber

Source

fn values<F: OutputFormat<Output = String>>( &self, reference: &Reference, hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Source

impl ComponentValues for TemplateTerm

Source

fn values<F: OutputFormat<Output = String>>( &self, _reference: &Reference, _hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Source

impl ComponentValues for TemplateTitle

Source

fn values<F: OutputFormat<Output = String>>( &self, reference: &Reference, hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Source

impl ComponentValues for TemplateVariable

Source

fn values<F: OutputFormat<Output = String>>( &self, reference: &Reference, _hints: &ProcHints, options: &RenderOptions<'_>, ) -> Option<ProcValues<F::Output>>

Implementors