Matcher

Struct Matcher 

pub struct Matcher<'a> { /* private fields */ }
Matcher for determining if references share the same primary contributors.

Uses the style’s substitution configuration to determine which contributor (author, editor, translator) should be used for comparison.

Implementations

Source

impl<'a> Matcher<'a>

pub fn new(style: &'a Style, default_config: &'a Config) -> Self

Build a matcher from the active style and default configuration.

pub fn contributors_match(&self, prev: &Reference, current: &Reference) -> bool

Check if primary contributors (authors/editors) match between two references. Uses the style’s substitution logic to determine the primary contributor.