Module reference

Module reference 

Reference types for the Citum processor.

This module re-exports types from citum_schema (for citations) and csl_legacy (for CSL-JSON bibliography data) for backward compatibility.

For new data, prefer using citum_schema::reference::InputReference which provides a more type-safe model with EDTF date support.

Structs

Citation
A citation containing one or more references.
CitationItem
A single citation item referencing a bibliography entry.
ContributorList
A list of contributors.
EdtfString
An EDTF string.
FlatName
A flattened name for internal processing.
Reference
The Reference model: a class-specific overlay reachable through accessor methods.
SimpleName
A simple name is just a string, with an optional location.
StructuredName
A structured name is a name broken down into its constituent parts.

Enums

CitationMode
Citation mode for author-date styles.
Contributor
A contributor can be a single string, a structured name, or a list of contributors.
LocatorType
Locator types for pinpoint citations.
MultilingualString
A string that can be represented in multiple languages and scripts.
NumOrStr
A value that could be either a number or a string.
Title
A title can be a single string, a structured title, or a multilingual title.

Type Aliases

Bibliography
A bibliography is a collection of references keyed by ID.