Bibliography-level rendering and output assembly helpers.
Functions
- refs_
to_ string - Render processed templates into a final bibliography string using
PlainTextformat. - refs_
to_ string_ slice_ with_ format - Render borrowed processed templates into a final bibliography string using a specific format.
- refs_
to_ string_ with_ format - Render processed templates into a final bibliography string using a specific format.
- render_
entry_ body_ with_ format - Render one processed bibliography entry body without outer entry/bibliography wrappers.