Citation-level rendering and output assembly helpers.
Functions
- citation_
to_ string - Render a processed template into a final citation string using
PlainTextformat. - citation_
to_ string_ with_ format - Render a processed template into a final citation string using a specific format.