Module format

Module format 

Output format trait for pluggable renderers.

Structs

ProcEntryMetadata
Metadata for a processed bibliography entry, used for interactivity.
QuoteMarks
Locale-resolved quote mark characters, threaded from GrammarOptions through to rendering so that styles using non-English quotation conventions (e.g. fr-FR guillemets) render correctly.
SemanticAttribute
Extra attributes applied to semantic wrappers when a renderer supports them.

Traits

OutputFormat
Trait for defining how to render template components into a specific format.

Functions

unicode_quote_marks
Return Unicode quote marks for a nesting depth.