Module format

Module format 

Output format trait for pluggable renderers.

Structs

ProcEntryMetadata
Metadata for a processed bibliography entry, used for interactivity.
SemanticAttribute
Extra attributes applied to semantic wrappers when a renderer supports them.

Traits

OutputFormat
Trait for defining how to render template components into a specific format.